@@ -90,7 +90,7 @@ class Tickets:
 
             RegistrationAddress = PartyLegalEntity.find(self.getInvoiceNameSpace("cac")+"RegistrationAddress")
             AddressTypeCode = RegistrationAddress.find(self.getInvoiceNameSpace("cbc")+"AddressTypeCode")
-            AddressTypeCode.text = str(data["emisor"]["ubigeo"])
+            AddressTypeCode.text = str(data["emisor"]["address_type"])
 
         
         #AccountingCustomerParty -> PartyName
